pocketpose.benchmarks - PocketPose 0.0.1 documentation

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Edit this page
Toggle table of contents sidebar

# `pocketpose.benchmarks`

The benchmarks module contains scripts to evaluate the models on various datasets.

## Submodules

- `pocketpose.benchmarks.eval_coco`
- `pocketpose.benchmarks.eval_coco_full`
- `pocketpose.benchmarks.eval_coco_sp`

## Package Contents

### Functions

`benchmark_coco`(model_name, images_path, annos_path, ...) |

pocketpose.benchmarks.benchmark_coco(model_name, images_path, annos_path, save_dir, dataset_type='coco_sp', det_annos_path=None, kpt_thr=0.3, save_vis=False)